/** Class to store the keywords and their visible states
* @author Matthew Carey
*/
package vishnu.testvis.visual;

public class KeyWordArray
{
    /** constant default number enabled */
    public static final int DEFAULT_ENABLED = 12;
    /** the word array */
    private String words[];
    /** the enabled array */
    private boolean enabled[];
    /** the count */
    private int count;
    /**
    * constructor
    * @param word array
    * @param count size
    * @param number enabled
    */
    public KeyWordArray(String words[],int count,int numEnabled)
    {
        this.words = words;
        this.count = count;
        enabled = new boolean[count];
        int theNumEnabled = count<numEnabled?count:numEnabled;
        for (int c = 0; c < numEnabled && c < count; c++)
            enabled[c]=true;
        if (count > theNumEnabled)
            for (int c = theNumEnabled; c < count; c++)
                enabled[c]=false;
    }
    /**
    * constructor
    * @param word array
    * @param count size
    */
    public KeyWordArray(String words[],int count)
    {
        this(words,count,DEFAULT_ENABLED);
    }

    public KeyWordArray()
    {
        this.count = 0;
        this.words = null;
        this.enabled = null;
    }

    /**
    * Find the size of the array
    * @return size of the array
    */
    public int getNumWords()
    {
        return count;
    }

    /**
    * Find the word at index
    * @param index of word
    * @return word at index
    */
    public String getWord(int index)
    {
        if (index >=0 && index < count)
           return this.words[index];
        return "Error out of index";
    }

    /**
    * Get state of word at index
    * @param index of word
    * @return state of word
    */
    public boolean getState(int index)
    {
        if (index >=0 && index < count)
           return this.enabled[index];
        return false;
    }

    /**
    * Set state of word at index
    * @param index of word
    * @param new state of word
    */
    public void setState(int index, boolean state)
    {
        if (index >=0 && index < count)
           this.enabled[index]=state;
    }

    /**
    * Get number of enabled words
    * @return number of enabled words
    */
    public int getNumEnabled()
    {
        int result = 0;
        for (int c = 0; c < count; c++)
            if (enabled[c]) result++;
        return result;
    }
}
